@@ -20,10 +20,9 @@
 #include <stdlib.h>
 
 /*
- * This release (4.10.7) is backward compatible with the
+ * This release (4.10.10) is backward compatible with the
  * 4.0.x, 4.1.x, 4.2.x, 4.3.x, 4.4.x, 4.5.x, 4.6.x, 4.7.x,
- * 4.8.x, 4.9.x, 4.10, 4.10.1, 4.10.2, 4.10.3, 4.10.4,
- * 4.10.5, 4.10.6 and 4.10.7 releases.
+ * 4.8.x, 4.9.x, 4.10.x and 4.11.X releases.
  * It, of course, is compatible with itself.
  */
 static char *compatible_version[] = {
@@ -39,7 +38,10 @@ static char *compatible_version[] = {
     "4.9", "4.9.1", "4.9.2", "4.9.3", "4.9.4", "4.9.5",
     "4.9.6",
     "4.10", "4.10.1", "4.10.2", "4.10.3", "4.10.4",
-    "4.10.5", "4.10.6", "4.10.7",
+    "4.10.5", "4.10.6", "4.10.7", "4.10.8", "4.10.9",
+    "4.10.10", "4.11", "4.12", "4.13", "4.14", "4.15",
+    "4.16", "4.17", "4.18", "4.19", "4.20", "4.21", "4.22",
+    "4.23", "4.24", "4.25",
     PR_VERSION
 };
 
@@ -55,8 +57,8 @@ static char *incompatible_version[] = {
     "3.0", "3.0.1",
     "3.1", "3.1.1", "3.1.2", "3.1.3",
     "3.5", "3.5.1",
-    "4.10.9",
-    "4.11", "4.11.1",
+    "4.26.1",
+    "4.27", "4.27.1",
     "10.0", "11.1", "12.14.20"
 };
 
